@@ -6,11 +6,15 @@ use Types::Standard qw/Str ArrayRef HashRef/;
 
 validate_subs (
     [qw/hello_hash hello_hashref/] => {
-            one   => [ Str ],
+        params => {
+            one   => [ Str, sub { 'I Have a Default Value' } ],
             two   => [ ArrayRef ],
             three => [ HashRef ],
+        },
+    },
+    [qw/a_list a_single_arrayref/] => {
+        params => [ [Str], [ArrayRef], [HashRef] ],
     },
-    [qw/a_list a_single_arrayref/] => [ [Str], [ArrayRef], [HashRef] ],
 );
 
 sub hello_hash {
@@ -37,4 +41,11 @@ sub a_single_arrayref {
     return $args;
 }
 
+sub okay_test {
+    my ($self) = shift;
+    my ($one, $two, $three) = $self->a_list( 'a', ['b'], { four => 'ahh' } );
+    return ($one, $two, $three);
+}
+
+
 1;
